# CLIXX

[![PyPI](https://img.shields.io/pypi/v/clixx)](https://pypi.org/project/clixx/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/clixx)](https://pypi.org/project/clixx/)
[![PyPI - Downloads](https://pepy.tech/badge/clixx/month)](https://pepy.tech/project/clixx)
[![PyPI - License](https://img.shields.io/pypi/l/clixx)](https://pypi.org/project/clixx/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

CLIXX is a command-line interface parser & framework for Python.

## Installation

Install from PyPI:

```shell
$ pip install clixx
```
